@@ -26,16 +26,17 @@
 ## (Config::Crontab) is for working with crontab files as a whole.
 package Config::Crontab;
 use strict;
+use warnings;
 use Carp;
+use 5.006_001;
 
-use vars qw( $VERSION @ISA );
-@ISA = qw(Config::Crontab::Base Config::Crontab::Container);
+our @ISA = qw(Config::Crontab::Base Config::Crontab::Container);
 
 ## these two are for the 'write' method
 use Fcntl;
 use File::Temp qw(:POSIX);
 
-$VERSION = '1.20';
+our $VERSION = '1.30';
 
 sub init {
     my $self = shift;
@@ -1296,10 +1297,10 @@ Example:
 
 package Config::Crontab::Block;
 use strict;
+use warnings;
 use Carp;
 
-use vars qw(@ISA);
-@ISA = qw(Config::Crontab::Base Config::Crontab::Container);
+our @ISA = qw(Config::Crontab::Base Config::Crontab::Container);
 
 sub init {
     my $self = shift;
@@ -1482,6 +1483,17 @@ sub active {
     return $active;
 }
 
+sub nolog {
+    my $self = shift;
+    return 1 unless @_;
+
+    my $nolog = shift;
+    local $_;
+    $_->nolog($nolog) for $self->select(-type => 'event');
+
+    return $nolog;
+}
+
 ############################################################
 ############################################################
 
@@ -1803,6 +1815,21 @@ Example:
 
     $block->active(0);  ## deactivate this block
 
+=head2 nolog(boolean)
+
+This is (currently) a SuSE-specific extension. From B<crontab(5)>:
+
+  If the uid of the owner is 0 (root), he can put a "-" as first
+  character of a crontab entry. This will prevent cron from writing a
+  syslog message about this command getting executed.
+
+B<nolog> enables adds or removes this hyphen for a given cron event
+line (regardless of whether the user is I<root> or not).
+
+Example:
+
+    $block->nolog(1);  ## quiet all entries in this block
+
 =head2 flag(string)
 
 Flags a block or an object inside a block with the specified data. The
@@ -1844,10 +1871,10 @@ Example:
 
 package Config::Crontab::Event;
 use strict;
+use warnings;
 use Carp;
 
-use vars qw(@ISA);
-@ISA = qw(Config::Crontab::Base);
+our @ISA = qw(Config::Crontab::Base);
 
 use constant RE_DT        => '(?:\d+|\*)(?:[-,\/]\d+)*';
 use constant RE_DM        => '\w{3}(?:,\w{3})*';
@@ -1855,6 +1882,7 @@ use constant RE_DTELEM    => '(?:\*|' . RE_DT . ')';
 use constant RE_DTMOY     => '(?:\*|' . RE_DT . '|' . RE_DM . ')';
 use constant RE_DTDOW     => RE_DTMOY;
 use constant RE_ACTIVE    => '^\s*(\#*)\s*';
+use constant RE_NOLOG     => '(-?)';  ## SuSE-specific extension
 use constant RE_SPECIAL   => '(\@(?:reboot|midnight|(?:year|annual|month|week|dai|hour)ly))';
 use constant RE_DATETIME  => '(' . RE_DTELEM . ')' .
                           '\s+(' . RE_DTELEM . ')' .
@@ -1863,10 +1891,10 @@ use constant RE_DATETIME  => '(' . RE_DTELEM . ')' .
                           '\s+(' . RE_DTDOW  . ')';
 use constant RE_USER      => '\s+(\S+)';
 use constant RE_COMMAND   => '\s+(.+?)\s*$';
-use constant SPECIAL      => RE_ACTIVE . RE_SPECIAL  . RE_COMMAND;
-use constant DATETIME     => RE_ACTIVE . RE_DATETIME . RE_COMMAND;
-use constant SYS_SPECIAL  => RE_ACTIVE . RE_SPECIAL  . RE_USER . RE_COMMAND;
-use constant SYS_DATETIME => RE_ACTIVE . RE_DATETIME . RE_USER . RE_COMMAND;
+use constant SPECIAL      => RE_ACTIVE . RE_NOLOG . RE_SPECIAL  . RE_COMMAND;
+use constant DATETIME     => RE_ACTIVE . RE_NOLOG . RE_DATETIME . RE_COMMAND;
+use constant SYS_SPECIAL  => RE_ACTIVE . RE_NOLOG . RE_SPECIAL  . RE_USER . RE_COMMAND;
+use constant SYS_DATETIME => RE_ACTIVE . RE_NOLOG . RE_DATETIME . RE_USER . RE_COMMAND;
 
 sub init {
     my $self = shift;
@@ -1875,6 +1903,7 @@ sub init {
 
     ## set defaults
     $self->active(1);
+    $self->nolog(0);
     $self->system(0);
 
     $self->special(undef);
@@ -1901,6 +1930,7 @@ sub init {
 	$self->datetime($args{'-datetime'}) if defined $args{'-datetime'};
 	$self->command($args{'-command'})   if $args{'-command'};
 	$self->active($args{'-active'})     if defined $args{'-active'};
+        $self->nolog($args{'-nolog'})       if defined $args{'-nolog'};
     }
     $rv = $self->data($args{'-data'})   if defined $args{'-data'};
 
@@ -1923,7 +1953,9 @@ sub data {
 	    if( @matches = $data =~ SYS_SPECIAL or
 		@matches = $data =~ SYS_DATETIME ) {
 		my $active = shift @matches;
+                my $nolog = shift @matches;
 		$self->active( ($active ? 0 : 1) );
+                $self->nolog( ($nolog ? 1 : 0) );
 		$self->command( pop @matches );
 		$self->user( pop @matches );
 		$self->datetime( \@matches );
@@ -1941,7 +1973,9 @@ sub data {
 	    if( @matches = $data =~ SPECIAL or
 		@matches = $data =~ DATETIME ) {
 		my $active = shift @matches;
+                my $nolog = shift @matches;
 		$self->active( ($active ? 0 : 1) );
+                $self->nolog( ($nolog ? 1 : 0) );
 		$self->command( pop @matches );
 		$self->user('');
 		$self->datetime( \@matches );
@@ -2058,9 +2092,12 @@ sub dump {
     my $self = shift;
     my $rv   = '';
 
-    $rv = ( $self->active
-	    ? '' 
-	    : '#' );
+    $rv .= ( $self->active
+             ? '' 
+             : '#' );
+    $rv .= ( $self->nolog
+             ? '-'
+             : '' );
     $rv .= $self->data;
     return $rv;
 }
@@ -2538,9 +2575,9 @@ Example:
 ## env objects are a few lines of comments followed by a variable assignment
 package Config::Crontab::Env;
 use strict;
+use warnings;
 
-use vars qw (@ISA);
-@ISA = qw(Config::Crontab::Base);
+our @ISA = qw(Config::Crontab::Base);
 
 use constant RE_ACTIVE   => '^\s*(\#*)\s*';
 use constant RE_VAR      => q!(["']?[^=]+?['"]?)\s*=\s*(.*)$!;
@@ -2787,9 +2824,9 @@ newline terminated.
 ## environment pattern
 package Config::Crontab::Comment;
 use strict;
+use warnings;
 
-use vars qw (@ISA);
-@ISA = qw(Config::Crontab::Base);
+our @ISA = qw(Config::Crontab::Base);
 
 sub init {
     my $self = shift;
@@ -2919,6 +2956,7 @@ not newline terminated.
 ## a virtual base class for top-level container classes
 package Config::Crontab::Container;
 use strict;
+use warnings;
 use Carp;
 
 sub up {
@@ -3052,9 +3090,10 @@ sub replace {
 ## the virtual base class of all Config::Crontab classes
 package Config::Crontab::Base;
 use strict;
+use warnings;
 use Carp;
 
-use vars qw( $AUTOLOAD );
+our $AUTOLOAD;
 
 sub new {
     my $self  = { };
@@ -3132,6 +3171,35 @@ __END__
 
 =item *
 
+Thanks to alert reader "Kirk" (no lastname given), we learn that some
+versions of Debian linux's "crontab -l" does not strip the internal
+crontab(1) comments (e.g., "DO NOT EDIT THIS FILE" and subsequent
+meta-data) at the start of user crontabs.
+
+This means that if you use Config::Crontab to edit a user's crontab
+file, those three headers will be added to the Config::Crontab object,
+and written back out again, and crontab(1) will add its own comments,
+effectively adding 3 comment lines each time you edit the crontab.
+
+You may use this little heuristic as a starting point for stripping
+those comments:
+
+    my $ct = new Config::Crontab;
+    $ct->read;
+    
+    ## make "crontab -l | crontab -" idempotent for Debian
+    for my $line ( grep { defined } ($ct->select(-type => 'comment'))[0..2] ) {
+        if( $line->data =~ qr(^# (?:DO NOT EDIT|[\(]\S+ installed|[\(]Cron version)) ) {
+            $ct->remove($line);
+        }
+    }
+    
+    ...
+    
+    $ct->write;
+
+=item *
+
 As of version 1.05, B<Config::Crontab> supports the user field (with
 optional ':group' and '/E<lt>login-classE<gt>') via the B<-system>
 initialization parameter, B<system> B<Event> method, or B<user>
@@ -3217,12 +3285,20 @@ alert; now using File::Temp.
 
 =back
 
-=head1 AUTHOR
-
-Scott Wiersdorf, E<lt>scott@perlcode.orgE<gt>
-
 =head1 SEE ALSO
 
 cron(8), crontab(1), crontab(5)
 
+=head1 AUTHOR
+
+Scott Wiersdorf, E<lt>scott@perlcode.orgE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2007 by Scott Wiersdorf
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.6 or,
+at your option, any later version of Perl 5 you may have available.
+
 =cut
